@@ -10,51 +10,54 @@
 #ifdef RADIUS_MODULE_POSTGRES_C
 # define RADIUS_MODULE 3
 #endif
-#ifdef RADIUS_MODULE_RADIUSD_C
+#ifdef RADIUS_MODULE_ODBC_C
 # define RADIUS_MODULE 4
 #endif
-#ifdef RADIUS_MODULE_ACCT_C 
+#ifdef RADIUS_MODULE_RADIUSD_C
 # define RADIUS_MODULE 5
 #endif
-#ifdef RADIUS_MODULE_AUTH_C
+#ifdef RADIUS_MODULE_ACCT_C 
 # define RADIUS_MODULE 6
 #endif
-#ifdef RADIUS_MODULE_EXEC_C
+#ifdef RADIUS_MODULE_AUTH_C
 # define RADIUS_MODULE 7
 #endif
-#ifdef RADIUS_MODULE_FILES_C
+#ifdef RADIUS_MODULE_EXEC_C
 # define RADIUS_MODULE 8
 #endif
-#ifdef RADIUS_MODULE_SQL_C
+#ifdef RADIUS_MODULE_FILES_C
 # define RADIUS_MODULE 9
 #endif
-#ifdef RADIUS_MODULE_PAM_C
+#ifdef RADIUS_MODULE_SQL_C
 # define RADIUS_MODULE 10
 #endif
-#ifdef RADIUS_MODULE_PROXY_C
+#ifdef RADIUS_MODULE_PAM_C
 # define RADIUS_MODULE 11
 #endif
-#ifdef RADIUS_MODULE_RADIUS_C
+#ifdef RADIUS_MODULE_PROXY_C
 # define RADIUS_MODULE 12
 #endif
-#ifdef RADIUS_MODULE_STAT_C
+#ifdef RADIUS_MODULE_RADIUS_C
 # define RADIUS_MODULE 13
 #endif
-#ifdef RADIUS_MODULE_SNMPSERV_C
+#ifdef RADIUS_MODULE_STAT_C
 # define RADIUS_MODULE 14
 #endif
-#ifdef RADIUS_MODULE_RADUTIL_C
+#ifdef RADIUS_MODULE_SNMPSERV_C
 # define RADIUS_MODULE 15
 #endif
-#ifdef RADIUS_MODULE_REWRITE_Y
+#ifdef RADIUS_MODULE_RADUTIL_C
 # define RADIUS_MODULE 16
 #endif
-#ifdef RADIUS_MODULE_CHECKRAD_C
+#ifdef RADIUS_MODULE_REWRITE_Y
 # define RADIUS_MODULE 17
 #endif
-#ifdef RADIUS_MODULE_BUILDDBM_C
+#ifdef RADIUS_MODULE_CHECKRAD_C
 # define RADIUS_MODULE 18
 #endif
+#ifdef RADIUS_MODULE_BUILDDBM_C
+# define RADIUS_MODULE 19
+#endif
 #ifdef RADIUS_MODULE_GRAM
-# define RADIUS_MODULE 4
+# define RADIUS_MODULE 5
 #endif
