@@ -1,21 +1,19 @@
 /* This file is part of GNU RADIUS.
- * Copyright (C) 2000, Sergey Poznyakoff
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
- *
- */
+   Copyright (C) 2000, Sergey Poznyakoff
+  
+   This program is free software; you can redistribute it and/or modify
+   it under the terms of the GNU General Public License as published by
+   the Free Software Foundation; either version 2 of the License, or
+   (at your option) any later version.
+  
+   This program is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+   GNU General Public License for more details.
+  
+   You should have received a copy of the GNU General Public License
+   along with this program; if not, write to the Free Software Foundation, 
+   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
 
 #ifndef _RADUTMP_H
 #define _RADUTMP_H
@@ -95,4 +93,19 @@ typedef struct port_stat {
 /* stat.c */
 PORT_STAT * findportbyindex(int ind);
 
+typedef struct _radut_file *radut_file_t;
+
+radut_file_t rut_setent(char *name, int append);
+void rut_endent(radut_file_t file);
+struct radutmp *rut_getent(radut_file_t file);
+int rut_putent(radut_file_t file, struct radutmp *ent);
+void rut_rewind(radut_file_t file);
+
+#define PUTENT_SUCCESS 0
+#define PUTENT_NOENT   1
+#define PUTENT_UPDATE  2
+
+int radutmp_putent(char *filename, struct radutmp *ut, int status);
+int radwtmp_putent(char *filename, struct radutmp *ut);
+
 #endif /* _RADUTMP_H */
