@@ -1,28 +1,26 @@
 /* This file is part of GNU RADIUS.
- * Copyright (C) 2000,2001, Sergey Poznyakoff
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
- *
- */
+   Copyright (C) 2000,2001, Sergey Poznyakoff
+  
+   This program is free software; you can redistribute it and/or modify
+   it under the terms of the GNU General Public License as published by
+   the Free Software Foundation; either version 2 of the License, or
+   (at your option) any later version.
+  
+   This program is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+   GNU General Public License for more details.
+  
+   You should have received a copy of the GNU General Public License
+   along with this program; if not, write to the Free Software Foundation, 
+   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
 
 #ifndef lint
 static char rcsid[] = 
-"$Id: checkrad.c,v 1.12 2001/04/17 06:42:09 gray Exp $";
+"$Id: checkrad.c,v 1.18 2001/11/28 15:40:46 gray Exp $";
 #endif
 
-#define RADIUS_MODULE 18
+#define RADIUS_MODULE_CHECKRAD_C
 
 #if defined(HAVE_CONFIG_H)
 # include <config.h>
@@ -63,13 +61,10 @@ struct check_instance {
 	int       timeout;
 	int       method;
 	char      *func;
-	RADCK_ARG *args;
+	envar_t   *args;
 	char      *hostname;
 };
 
-RADCK_ARG *lookup(RADCK_ARG *arg, char *name);
-RADCK_ARG *dup_arg(RADCK_ARG *arg);
-RADCK_ARG *merge_args(RADCK_ARG *prim, RADCK_ARG *sec);
 struct check_instance * create_instance(struct check_instance *cptr,
 					NAS *nas, struct radutmp *up);
 void free_instance(struct check_instance *cptr);
@@ -77,51 +72,6 @@ char * slookup(struct check_instance *checkp, char *name, char *defval);
 int ilookup(struct check_instance *checkp, char *name, int defval);
 int compare(struct check_instance *checkp, char *str);
 
-
-RADCK_ARG *
-lookup(arg, name)
-	RADCK_ARG *arg;
-	char    *name;
-{
-	for (; arg && strcmp(arg->name, name); arg = arg->next)
-		;
-	return arg;
-}
-
-RADCK_ARG *
-dup_arg(arg)
-	RADCK_ARG *arg;
-{
-	RADCK_ARG *dp;
-
-	dp = alloc_entry(sizeof(*arg));
-	dp->name  = arg->name;
-	dp->value = arg->value;
-	return dp;
-}
-
-RADCK_ARG *
-merge_args(prim, sec)
-	RADCK_ARG *prim;
-	RADCK_ARG *sec;
-{
-	RADCK_ARG *list, *p;
-
-	list = NULL;
-	for (; sec; sec = sec->next)
-		if (!lookup(prim, sec->name)) {
-			p = dup_arg(sec);
-			p->next = list;
-			list = p;
-		}
-	for (; prim; prim = prim->next) {
-		p = dup_arg(prim);
-		p->next = list;
-		list = p;
-	}
-	return list;
-}
-
 struct check_instance *
 create_instance(cptr, nas, up)
 	struct check_instance *cptr;
@@ -146,7 +96,7 @@ create_instance(cptr, nas, up)
 	cptr->hostname = nas->shortname ? nas->shortname : nas->longname;
 	
 	cptr->method = radck_type->method;
-	cptr->args = merge_args((RADCK_ARG*) nas->args, radck_type->args);
+	cptr->args = envar_merge_lists((envar_t*) nas->args, radck_type->args);
 	cptr->func = slookup(cptr, "function", NULL);
 	return cptr;
 }
@@ -155,7 +105,7 @@ void
 free_instance(cptr)
 	struct check_instance *cptr;
 {
-	free_slist((struct slist*)cptr->args, NULL);
+	envar_free_list(cptr->args);
 }
 
 char *
@@ -164,11 +114,7 @@ slookup(checkp, name, defval)
 	char *name;
 	char *defval;
 {
-	RADCK_ARG *arg;
-
-	if (arg = lookup(checkp->args, name))
-		return arg->value;
-	return defval;
+	return envar_lookup_str(checkp->args, name, defval);
 }
 
 int
@@ -177,11 +123,7 @@ ilookup(checkp, name, defval)
 	char *name;
 	int defval;
 {
-	RADCK_ARG *arg;
-
-	if (arg = lookup(checkp->args, name))
-		return atoi(arg->value);
-	return defval;
+	return envar_lookup_int(checkp->args, name, defval);
 }
 	
 int
@@ -224,23 +166,23 @@ checkrad_xlat(checkp, str)
 				ptr = checkp->sid;
 				break;
 			case 'd':
-				radsprintf(buf, sizeof(buf), "%lu",
+				snprintf(buf, sizeof(buf), "%lu",
 					   strtol(checkp->sid, NULL, 16));
 				ptr = buf;
 				break;
 			case 'p':
-				radsprintf(buf, sizeof(buf), "%d", 
+				snprintf(buf, sizeof(buf), "%d", 
 					checkp->port);
 				ptr = buf;
 				break;
 			case 'P':
-				radsprintf(buf, sizeof(buf), "%d",
+				snprintf(buf, sizeof(buf), "%d",
 					 checkp->port + 1);
 				ptr = buf;
 				break;
 			case 'i':
-				radsprintf(buf, sizeof(buf), "%I",
-					   checkp->ip);
+				snprintf(buf, sizeof(buf), "%s",
+					   format_ipaddr(checkp->ip));
 				ptr = buf;
 				break;
 			default:
@@ -298,7 +240,7 @@ converse(type, sp, pdu, closure)
 		case SMI_INTEGER:
 		case SMI_COUNTER32:
 		case SMI_COUNTER64:
-			radsprintf(buf, sizeof(buf), "%d", vlist->var_int);
+			snprintf(buf, sizeof(buf), "%d", vlist->var_int);
 			rc = compare(checkp, buf);
 			debug(2, ("(INT) %d: %d", vlist->var_int, rc));
 			break;
@@ -436,6 +378,7 @@ finger_check(checkp, nas)
 	struct check_instance *checkp;
 	NAS *nas;
 {
+	char *arg;
 	char namebuf[RUT_NAMESIZE+1];
 	int namelen;
 	register FILE *fp;
@@ -452,14 +395,16 @@ finger_check(checkp, nas)
 	char *ptr;
 	RETSIGTYPE (*handler)() = SIG_IGN;
 	unsigned int to;
-	
+
+	arg = checkrad_xlat(checkp, slookup(checkp, "arg", "%u"));
 	/* Copy at most RUT_NAMESIZE bytes from the user name */
-	ptr = checkp->name;
+	ptr = arg;
 	for (i = 0; i < RUT_NAMESIZE && *ptr; ++ptr, ++i)
 		namebuf[i] = *ptr;
 	namebuf[i] = 0;
 	namelen = i;
-
+	efree(arg);
+	
 	peername = slookup(checkp, "host", nas->longname);
 	if (!(hp = gethostbyname(peername))) {
 		radlog(L_ERR, _("unknown host: %s"), peername);
