@@ -18,7 +18,7 @@
 #define RADIUS_MODULE_SQL_C
 #ifndef lint
 static char rcsid[] =
-"@(#) $Id: sql.c,v 1.29 2001/12/27 13:06:03 gray Exp $";
+"@(#) $Id: sql.c,v 1.29.2.1 2002/03/19 16:11:44 gray Exp $";
 #endif
 
 #if defined(HAVE_CONFIG_H)
@@ -1269,8 +1269,10 @@ rad_sql_retrieve_pairs(conn, query, return_pairs, op_too)
 		
 		pair = install_pair(attribute, op, value);
 		
-		if (pair)
-			avl_add_list(return_pairs, pair);
+                if (pair) {
+			avl_merge(return_pairs, &pair);
+			avl_free(pair);
+		}
 	}
 
 	disp_sql_free(sql_cfg.interface, conn, data);
