@@ -1,25 +1,23 @@
 /* This file is part of GNU RADIUS.
- * Copyright (C) 2000, Sergey Poznyakoff
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
- *
- */
+   Copyright (C) 2000, Sergey Poznyakoff
+ 
+   This program is free software; you can redistribute it and/or modify
+   it under the terms of the GNU General Public License as published by
+   the Free Software Foundation; either version 2 of the License, or
+   (at your option) any later version.
+ 
+   This program is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+   GNU General Public License for more details.
+ 
+   You should have received a copy of the GNU General Public License
+   along with this program; if not, write to the Free Software Foundation,
+   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
 
 #ifndef lint
 static char rcsid[] = 
-"$Id: radlast.c,v 1.5 2001/04/10 09:32:47 gray Exp $";
+"$Id: radlast.c,v 1.11 2001/11/16 15:01:44 gray Exp $";
 #endif
 
 #ifdef HAVE_CONFIG_H
@@ -39,12 +37,10 @@ static char rcsid[] =
 #include <assert.h>
 #include <signal.h>
 #include <netinet/in.h>
-#ifdef HAVE_GETOPT_LONG
-# include <getopt.h>
-#endif
 
-#include <sysdep.h>
-#include <radiusd.h>
+#include <getopt1.h>
+#include <radius.h>
+#include <radpaths.h>
 #include <radutmp.h>
 #include <log.h>
 
@@ -81,12 +77,6 @@ WTMP *find_wtmp_nas(WTMP *first, struct radutmp *bp);
 WTMP *find_wtmp_nas_port(WTMP *first, struct radutmp *bp);
 WTMP *find_wtmp_nas_port_sid(WTMP *first, struct radutmp *bp);
 
-NAS * nas_find(UINT4 ipaddr);
-NAS * nas_find_by_name(char *name);
-char * nas_name(UINT4 ipaddr);
-
-extern NAS *naslist;
-
 UINT4 host_ip = 0;
 UINT4 nas_ip = 0;
 int port = 0;
@@ -116,7 +106,7 @@ WTMP *login_list;
 WTMP *nas_updown_list;
 
 #define OPTSTR "?0123456789c:d:f:h:mn:lLp:st:w"
-#ifdef HAVE_GETOPT_LONG
+
 struct option longopt[] = {
 	"count",              required_argument, 0, 'c',
 	"config-directory",   required_argument, 0, 'd',
@@ -132,11 +122,6 @@ struct option longopt[] = {
 	"wide",               no_argument,       0, 'w',
 	0
 };
-# define GETOPT getopt_long
-#else
-# define longopt 0
-# define GETOPT(ac,av,os,lo,li) getopt(ac,av,os)
-#endif
 
 int
 main(argc, argv)
@@ -145,9 +130,10 @@ main(argc, argv)
 {
 	int c;
 	char *p;
+	char *nas_name = NULL;
 
 	initlog(argv[0]);
-	while ((c = GETOPT(argc, argv, OPTSTR, longopt, NULL)) != EOF)
+	while ((c = getopt_long(argc, argv, OPTSTR, longopt, NULL)) != EOF)
 		switch (c) {
 		case '0': case '1': case '2': case '3': case '4':
 		case '5': case '6': case '7': case '8': case '9':
@@ -186,17 +172,7 @@ main(argc, argv)
 			mark_missing_stops++;
 			break;
 		case 'n':
-			nas_ip = get_ipaddr(optarg);
-			if (!nas_ip) {
-				NAS *nas;
-				read_naslist();
-				nas = nas_find_by_name(optarg);
-				if (nas)
-					nas_ip = nas->ipaddr;
-				else
-					radlog(L_ERR, "unknown nas: %s", optarg);
-			}
-			nas_ip = htonl(nas_ip);
+			nas_name = optarg;
 			break;
 		case 'l':
 			long_fmt++;
@@ -233,10 +209,34 @@ main(argc, argv)
 	}
 	radpath_init();
 	read_naslist();
+
+	if (nas_name) {
+		nas_ip = get_ipaddr(nas_name);
+		if (!nas_ip) {
+			NAS *nas = nas_lookup_name(nas_name);
+			if (nas)
+				nas_ip = nas->ipaddr;
+			else {
+				radlog(L_ERR, "unknown nas: %s", nas_name);
+				return 1;
+			}
+		}	
+		nas_ip = htonl(nas_ip);
+	}
 	radwtmp();
 	return 0;
 }
 
+int
+read_naslist()
+{
+	int rc;
+	char *path = mkfilename(radius_dir, RADIUS_NASLIST);
+	rc = nas_read_file(path);
+	efree(path);
+	return rc;
+}
+
 #if 0
 int
 rawread()
@@ -266,7 +266,7 @@ rawread()
 		       ut.login,
 		       
 		       nas_name_len, nas_name_len,
-		       nas_name(ntohl(ut.nas_address)),
+		       nas_ip_to_name(ntohl(ut.nas_address)),
 
 		       ut.nas_port,
 
@@ -662,7 +662,7 @@ print_entry(pp, bp, mark)
 		       bp->login,
 		       
 		       nas_name_len, nas_name_len,
-		       nas_name(ntohl(bp->nas_address)),
+		       nas_ip_to_name(ntohl(bp->nas_address)),
 
 		       bp->nas_port,
 
@@ -687,7 +687,7 @@ print_entry(pp, bp, mark)
 		       bp->login,
 		       
 		       nas_name_len, nas_name_len,
-		       nas_name(ntohl(bp->nas_address)),
+		       nas_ip_to_name(ntohl(bp->nas_address)),
 
 		       bp->nas_port,
 
@@ -744,13 +744,12 @@ print_reboot_entry(bp)
 	       namesize, namesize,
 	       s,
 		       
-	       nas_name(ntohl(bp->nas_address)),
+	       nas_ip_to_name(ntohl(bp->nas_address)),
 	       ct, ct + 11);
 }
 
 
 char usage_str[] =
-#ifdef HAVE_GETOPT_LONG
 "usage: radlast [options] [user ...]\n"
 "Options are:\n"
 "    -c, --count NUMBER          show at most NUMBER records\n"
@@ -764,31 +763,15 @@ char usage_str[] =
 "    -p, --port PORT             show logins from given PORT\n"
 "    -s, --show-seconds          show the login session duration in seconds\n"
 "    -w, --wide                  widen the duration field to show seconds\n"
-"    -?, --help                  show this help info"
-#else
-"usage: radlast [options] [user ...]\n"
-"Options are:\n"
-"    -c NUMBER                   show at most NUMBER records\n"
-"    -NUMBER                     the same as above\n"
-"    -f FILENAME                 use FILENAME as radwtmp\n"
-"    -h IPADDR                   show logins with IPADDR\n"
-"    -m                          mark records with missed stops with bump (!)\n"
-"    -n NAS                      show logins from given NAS\n"
-"    -l                          use long output format\n"
-"    -L                          display license and exit\n"
-"    -p PORT                     show logins from given PORT\n"
-"    -s                          show the login session duration in seconds\n"
-"    -w                          widen the duration field to show seconds\n"
-"    -?                          show this help info"
-#endif
-;
+"    -?, --help                  show this help info" ;
 
 void
 usage(void)
 {
-	fprintf(stderr,
-		"%s\n",
-		usage_str);
+	printf("%s\n"
+		"\nReport bugs to <%s>\n",
+		usage_str,
+		bug_report_address);
 	exit(1);
 }
 
